@@ -11,7 +11,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage accounts
-	* @version $Id: class.accounts_ldap.inc.php,v 1.101.2.13.2.33 2004/07/29 07:35:24 fipsfuchs Exp $
+	* @version $Id: class.accounts_ldap.inc.php,v 1.101.2.13.2.35 2005/08/04 23:24:49 skwashd Exp $
 	*/
 
 	/**
@@ -240,11 +240,11 @@
 		{
 			if(empty($query) || $query == "*")
 			{
-				$filter = '(&(uidnumber=*)(objectclass=posixaccount))';
+				$filter = '(&(uidnumber=*)(objectclass=phpgwaccount))';
 			}
 			else
 			{
-				$filter = "(&(uidnumber=*)(objectclass=posixaccount)(|(uid=*$query*)(sn=*$query*)(cn=*$query*)(givenname=*$query*)))";
+				$filter = "(&(uidnumber=*)(objectclass=phpgwaccount)(|(uid=*$query*)(sn=*$query*)(cn=*$query*)(givenname=*$query*)))";
 			}
 			$sri = ldap_search($this->ds, $this->user_context, $filter);
 			$allValues = ldap_get_entries($this->ds, $sri);
@@ -277,11 +277,11 @@
 		{
 			if(empty($query) || $query == "*")
 			{
-				$filter = '(&(gidnumber=*)(objectclass=posixgroup))';
+				$filter = '(&(gidnumber=*)(objectclass=phpgwgroup))';
 			}
 			else
 			{
-				$filter = "(&(gidnumber=*)(objectclass=posixgroup)(|(uid=*$query*)(sn=*$query*)(cn=*$query*)(givenname=*$query*)))";
+				$filter = "(&(gidnumber=*)(objectclass=phpgwgroup)(|(uid=*$query*)(sn=*$query*)(cn=*$query*)(givenname=*$query*)))";
 			}
 			$sri = ldap_search($this->ds, $this->group_context, $filter);
 			$allValues = ldap_get_entries($this->ds, $sri);
@@ -745,13 +745,10 @@
 				$entry['objectclass'][] = 'phpgwContact'; // shouldn't be structural
 				$entry['phpgwcontactid'] = (int)$account_info['person_id'];
 			}
-			else
-			{
-				$entry['objectclass'][]       = 'account';
-			}
-
+			
 			// additional attributes from the phpgw for groups
 			$entry['objectclass'][]       = 'posixAccount';
+			$entry['objectclass'][]       = 'account';
 			$entry['cn']                  = utf8_encode($this->get_fullname($account_info['account_firstname'], $account_info['account_lastname']));
 			$entry['uidnumber']           = $account_info['account_id'];
 			$entry['uid']                 = $account_info['account_lid'];
