@@ -7,7 +7,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: functions.inc.php,v 1.121.2.13.2.22 2004/11/06 15:34:26 powerstat Exp $
+	* @version $Id: functions.inc.php,v 1.121.2.13.2.24 2005/08/26 01:33:15 skwashd Exp $
 	*/
 
 	
@@ -25,9 +25,9 @@
 	include_once(PHPGW_API_INC.'/common_functions.inc.php');
 	
 	/*!
-	 @function lang
-	 @abstract function to handle multilanguage support
-	*/
+	  @function lang
+	  @abstract function to handle multilanguage support
+	 */
 	function lang($key,$m1='',$m2='',$m3='',$m4='',$m5='',$m6='',$m7='',$m8='',$m9='',$m10='')
 	{
 		if(is_array($m1))
@@ -42,6 +42,34 @@
 		return $value;
 	}
 
+	function clean_vars($vars)
+	{
+		if ( !is_array($vars) )
+		{
+			$data_cleaner = createObject('phpgwapi.data_cleaner', $vars);
+			return $data_cleaner->clean();
+		}
+		
+		foreach ( $vars as $key => $val )
+		{
+			$vars[$key] = clean_vars($val);
+		}
+		return $vars;
+	}
+
+	// Remove this and I will make sure that you lose important parts of your anatomy - skwashd
+	$GLOBALS['RAW_REQUEST'] = $_REQUEST; // if you really need the raw value
+	$to_cleans = array('_GET', '_POST', '_COOKIE', '_REQUEST');
+	foreach ( $to_cleans as $to_clean )
+	{
+		if ( isset($GLOBALS[$to_clean]) && is_array($GLOBALS[$to_clean]) && count($GLOBALS[$to_clean]) )
+		{
+			$GLOBALS['to_clean'] = clean_vars($GLOBALS['to_clean']);
+			$GLOBALS["HTTP{$to_change}_VARS"] = $GLOBALS[$to_change];//legacy app support - will be dropped in 18
+		}
+	}
+
+
 	/* Make sure the header.inc.php is current. */
 	if ($GLOBALS['phpgw_info']['server']['versions']['header'] < $GLOBALS['phpgw_info']['server']['versions']['current_header'])
 	{
@@ -54,20 +82,20 @@
 	if (!isset($GLOBALS['phpgw_info']['flags']['currentapp']))
 	{
 		/* This object does not exist yet. */
-	/*	$GLOBALS['phpgw']->log->write(array('text'=>'W-MissingFlags, currentapp flag not set'));*/
+		/*	$GLOBALS['phpgw']->log->write(array('text'=>'W-MissingFlags, currentapp flag not set'));*/
 
 		echo '<b>!!! YOU DO NOT HAVE YOUR $GLOBALS[\'phpgw_info\'][\'flags\'][\'currentapp\'] SET !!!';
 		echo '<br />!!! PLEASE CORRECT THIS SITUATION !!!</b>';
 	}
 
 	magic_quotes_runtime(false);
-// Can't use this yet - errorlog hasn't been created.
-//	print_debug('sane environment','messageonly','api');
+	// Can't use this yet - errorlog hasn't been created.
+	//	print_debug('sane environment','messageonly','api');
 
 	/****************************************************************************\
-	* Multi-Domain support                                                       *
-	\****************************************************************************/
-	
+	 * Multi-Domain support                                                       *
+	 \****************************************************************************/
+
 	/* make them fix their header */
 	if (!isset($GLOBALS['phpgw_domain']))
 	{
@@ -113,8 +141,8 @@
 		unset ($GLOBALS['phpgw_domain']); // we kill this for security reasons
 	}
 
-// Can't use this yet - errorlog hasn't been created.
-//	print_debug('domain',@$GLOBALS['phpgw_info']['user']['domain'],'api');
+	// Can't use this yet - errorlog hasn't been created.
+	//	print_debug('domain',@$GLOBALS['phpgw_info']['user']['domain'],'api');
 
 	 /****************************************************************************\
 	 * These lines load up the API, fill up the $phpgw_info array, etc            *
@@ -455,5 +483,5 @@ my new logging stuff.  So I changed it.
 			include_once(PHPGW_APP_INC . '/header.inc.php');
 		}
 	}
-	
+
 	error_reporting(E_ERROR | E_WARNING | E_PARSE);
