@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	// $Id: tables_update.inc.php,v 1.53.2.9.2.38 2005/01/03 05:39:41 skwashd Exp $
+	// $Id: tables_update.inc.php,v 1.53.2.9.2.41 2005/08/26 01:40:22 skwashd Exp $
 	// $Source: /cvsroot/phpgwapi/phpgwapi/setup/tables_update.inc.php,v $
 
 	/* Include older phpGroupWare update support */
@@ -1654,7 +1654,7 @@
 		////global $setup_info,$phpgw_setup;
 		$db1 =& $GLOBALS['phpgw_setup']->db; 
 		$db1->auto_stripslashes = False;
-		$db1->Halt_On_Error = 'report';
+		//$db1->Halt_On_Error = 'report';
 
 		/* Check if addressmaster exist  */
 		$GLOBALS['phpgw_setup']->oProc->query("SELECT config_name, config_value FROM phpgw_config WHERE config_name = 'addressmaster'");
@@ -1777,4 +1777,23 @@
                 $GLOBALS['setup_info']['phpgwapi']['currentver'] = '0.9.16.005';
                 return $GLOBALS['setup_info']['phpgwapi']['currentver'];
         }
+
+	$test[] = '0.9.16.005';
+	function phpgwapi_upgrade0_9_16_005()
+	{
+		//this was never publicly released!
+		return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '0.9.16.006';
+	}
+
+	$test[] = '0.9.16.006';
+	function phpgwapi_upgrade0_9_16_006()
+	{
+		return $GLOBALS['setup_info']['phpgwapi']['currentver'] = '0.9.16.007';
+	}
+
+	$test[] = '0.9.16.007';
+	function phpgwapi_upgrade0_9_16_007()
+	{
+		return $GLOBALS['phpgw_info']['phpgwapi']['currentver'] = '0.9.16.008';
+	}		
 ?>
