@@ -23,7 +23,7 @@
 	* along with this program; if not, write to the Free Software       *
 	* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.         *
 	\*******************************************************************/
-	/* $Id: class.uiprojects.inc.php,v 1.47.2.7.2.42 2004/01/05 13:33:47 ceb Exp $ */
+	/* $Id: class.uiprojects.inc.php,v 1.47.2.7.2.43 2005/05/23 22:03:56 ceb Exp $ */
 	// $Source: /cvsroot/phpgroupware/projects/inc/class.uiprojects.inc.php,v $
 
 	class uiprojects
@@ -621,15 +621,18 @@
 			return $coordinator_list;
 		}
 
-		function employee_format($data)
+		function employee_format($data,$selected='')
 		{
 			$type		= ($data['type']?$data['type']:'list');
 			$project_id	= ($data['project_id']?$data['project_id']:0);
 
-			$selected = $this->boprojects->get_acl_for_project($project_id);
 			if (!is_array($selected))
 			{
-				$selected = array();
+				$selected = $this->boprojects->get_acl_for_project($project_id);
+				if (!is_array($selected))
+				{
+					$selected = array();
+				}
 			}
 
 			switch($type)
@@ -815,12 +818,14 @@
 			}
 			else
 			{
-				$values = array
-				(
-					'parent'	=> $pro_main,
-					'status'	=> 'active'
-				);
-
+				if (!is_array($values))
+				{
+					$values = array
+					(
+						'parent'	=> $pro_main,
+						'status'	=> 'active'
+					);
+				}
 				$GLOBALS['phpgw']->template->set_var('choose','<input type="checkbox" name="values[choose]" value="True">');
 
 				if (!$values['smonth'])
@@ -837,6 +842,11 @@
 				{
 					$values['syear'] = date('Y',time());
 				}
+				
+				if (isset($values['eday']) && isset($values['emonth']) && isset($values['eyear']))
+				{
+					$values['edate'] = mktime(0,0,0,$values['emonth'],$values['eday'],$values['eyear']);
+				}
 			}
 
 			$GLOBALS['phpgw']->template->set_var('start_date_select',$GLOBALS['phpgw']->common->dateformatorder($this->sbox->getYears('values[syear]',$values['syear']),
@@ -925,7 +935,7 @@
 					$GLOBALS['phpgw']->template->set_var('cat',$this->boprojects->cats->id2name($main['cat']));
 					$this->cat_id = $parent['cat'];
 					$GLOBALS['phpgw']->template->set_var('book_activities_list',$this->boprojects->select_pro_activities($project_id, $pro_main, False));				
-    				$GLOBALS['phpgw']->template->set_var('bill_activities_list',$this->boprojects->select_pro_activities($project_id, $pro_main, True));
+					$GLOBALS['phpgw']->template->set_var('bill_activities_list',$this->boprojects->select_pro_activities($project_id, $pro_main, True));
 				}
 
 				$GLOBALS['phpgw']->template->set_var('lang_main',lang('Main project:'));
@@ -965,7 +975,7 @@
 					$GLOBALS['phpgw']->template->set_var('clisthandle','');
 					$GLOBALS['phpgw']->template->fp('cfieldhandle','cfield',True);
 
-					$GLOBALS['phpgw']->template->set_var('employee_list',$this->employee_format(array('type' => 'field','project_id' => $project_id)));
+					$GLOBALS['phpgw']->template->set_var('employee_list',$this->employee_format(array('type' => 'field','project_id' => $project_id),$values['employees']));
 
 					$GLOBALS['phpgw']->template->set_var('elisthandle','');
 					$GLOBALS['phpgw']->template->fp('efieldhandle','efield',True);
@@ -975,7 +985,7 @@
 						$GLOBALS['phpgw']->template->set_var('cfieldhandle','');
 						$GLOBALS['phpgw']->template->fp('clisthandle','clist',True);
 
-					$GLOBALS['phpgw']->template->set_var('employee_list',$this->employee_format(array('project_id' => $project_id)));
+					$GLOBALS['phpgw']->template->set_var('employee_list',$this->employee_format(array('project_id' => $project_id),$values['employees']));
 						$GLOBALS['phpgw']->template->set_var('efieldhandle','');
 						$GLOBALS['phpgw']->template->fp('elisthandle','elist',True);
 					break;
@@ -1379,6 +1389,7 @@
 				if (is_array($error))
 				{
 					$GLOBALS['phpgw']->template->set_var('message',$GLOBALS['phpgw']->common->error_list($error));
+					$GLOBALS['phpgw']->template->set_var($values);
 				}
 				else
 				{
